# Tippie

 A simple package to type hint programs for you automatically.

# Why should you use it?

The main reason I am working on it is to save time when I type hint. I was working on my chess game once and when it came to type hinting, it took a lot of my time.

# How to use it?
`tippie [file_name]`

## Have a great day!